Module result
arrdb_
exec
0.0.1
Module result
Module Items
Structs
Enums
Type Aliases
In crate arrdb_
exec
arrdb_exec
Module
result
Structs

Scalar
Coord
A coordinate that was sliced out to a single value (e.g.
lat=42.5
).
Enums

Execution
Result
The result of executing a query through the Session.
Type Aliases

Exec
Result
Convenience type alias.